from __future__ import absolute_import
print("\nPlease cite the following paper when using nnUNet:\nIsensee, Fabian, et al. \"nnU-Net: Breaking the Spell on "
      "Successful Medical Image Segmentation.\" arXiv preprint arXiv:1904.08128 (2019).")
print("If you have questions or suggestions, feel free to open an issue at https://github.com/MIC-DKFZ/nnUNet\n")

from . import *